==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/PropertyEditorDescriptionObjectDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { PropertyEditorDescriptionObjectDescription } from "./PropertyEditorDescriptionObjectDescription";
/**
 * @hidden
 */
var PropertyEditorDescriptionObjectDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(PropertyEditorDescriptionObjectDescriptionMetadata, _super);
    function PropertyEditorDescriptionObjectDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    PropertyEditorDescriptionObjectDescriptionMetadata.b = function (a) {
        if (PropertyEditorDescriptionObjectDescriptionMetadata.a == null) {
            PropertyEditorDescriptionObjectDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            PropertyEditorDescriptionObjectDescriptionMetadata.c(PropertyEditorDescriptionObjectDescriptionMetadata.a);
        }
        if (a.j(PropertyEditorDescriptionObjectDescriptionMetadata.a)) {
            return;
        }
        a.y(PropertyEditorDescriptionObjectDescriptionMetadata.a);
    };
    PropertyEditorDescriptionObjectDescriptionMetadata.c = function (a) {
        a.item("DescriptionType", "String");
        a.item("Properties", "Collection:PropertyEditorPropertyDescription:PropertyEditorPropertyDescriptionCollection:PropertyEditorPropertyDescription");
    };
    PropertyEditorDescriptionObjectDescriptionMetadata.d = function (a) {
        PropertyEditorDescriptionObjectDescriptionMetadata.b(a);
        a.aa("PropertyEditorDescriptionObject", function () { return new PropertyEditorDescriptionObjectDescription(); });
        a.z("PropertyEditorDescriptionObject", PropertyEditorDescriptionObjectDescriptionMetadata.a);
    };
    PropertyEditorDescriptionObjectDescriptionMetadata.$t = markType(PropertyEditorDescriptionObjectDescriptionMetadata, 'PropertyEditorDescriptionObjectDescriptionMetadata');
    PropertyEditorDescriptionObjectDescriptionMetadata.a = null;
    return PropertyEditorDescriptionObjectDescriptionMetadata;
}(Base));
export { PropertyEditorDescriptionObjectDescriptionMetadata };

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/PropertyEditorDescriptionObjectDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { PropertyEditorDescriptionObjectDescription } from "./PropertyEditorDescriptionObjectDescription";
/**
 * @hidden
 */
var PropertyEditorDescriptionObjectDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(PropertyEditorDescriptionObjectDescriptionMetadata, _super);
    function PropertyEditorDescriptionObjectDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    PropertyEditorDescriptionObjectDescriptionMetadata.b = function (a) {
        if (PropertyEditorDescriptionObjectDescriptionMetadata.a == null) {
            PropertyEditorDescriptionObjectDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            PropertyEditorDescriptionObjectDescriptionMetadata.c(PropertyEditorDescriptionObjectDescriptionMetadata.a);
        }
        if (a.k(PropertyEditorDescriptionObjectDescriptionMetadata.a)) {
            return;
        }
        a.aa(PropertyEditorDescriptionObjectDescriptionMetadata.a);
    };
    PropertyEditorDescriptionObjectDescriptionMetadata.c = function (a) {
        a.item("DescriptionType", "String");
        a.item("Properties", "Collection:PropertyEditorPropertyDescription:PropertyEditorPropertyDescriptionCollection:PropertyEditorPropertyDescription");
    };
    PropertyEditorDescriptionObjectDescriptionMetadata.d = function (a) {
        PropertyEditorDescriptionObjectDescriptionMetadata.b(a);
        a.ac("PropertyEditorDescriptionObject", function () { return new PropertyEditorDescriptionObjectDescription(); });
        a.ab("PropertyEditorDescriptionObject", PropertyEditorDescriptionObjectDescriptionMetadata.a);
    };
    PropertyEditorDescriptionObjectDescriptionMetadata.$t = markType(PropertyEditorDescriptionObjectDescriptionMetadata, 'PropertyEditorDescriptionObjectDescriptionMetadata');
    PropertyEditorDescriptionObjectDescriptionMetadata.a = null;
    return PropertyEditorDescriptionObjectDescriptionMetadata;
}(Base));
export { PropertyEditorDescriptionObjectDescriptionMetadata };
